import DyteEventEmitter from '../utils/DyteEventEmitter';
import DyteSelf from './DyteSelf';
export declare enum MessageType {
    text = "text",
    image = "image",
    file = "file",
    poll = "poll"
}
export declare const messageTypes: string[];
export interface BaseMessage<T extends MessageType> {
    type: T;
    userId: string;
    displayName: string;
    time: Date;
    id: string;
    isEdited?: boolean;
    read?: boolean;
    pluginId?: string;
    pinned?: boolean;
}
export interface TextMessage extends BaseMessage<MessageType.text> {
    message: string;
}
export interface ImageMessage extends BaseMessage<MessageType.image> {
    link: string;
}
export interface FileMessage extends BaseMessage<MessageType.file> {
    name: string;
    size: number;
    link: string;
}
export declare type Message = TextMessage | ImageMessage | FileMessage;
/**
 * This is the chat module, which can be used to send and receive messages from the meeting.
 * @module DyteChat
 * @typicalname meeting.chat
 */
export default class DyteChat extends DyteEventEmitter {
    #private;
    /**
     * An array of chat messages.
     */
    messages: Message[];
    constructor(self: DyteSelf);
    /**
     * Sends a chat text message to the room.
     * @param message The message that must be sent to the room.
     */
    sendTextMessage(message: string): Promise<void>;
    /**
     * Sends an image message to the meeting.
     * @param image The image that is to be sent.
     */
    sendImageMessage(image: File): Promise<void>;
    /**
     * Sends a file to the meeting.
     * @param file A File object.
     */
    sendFileMessage(file: File): Promise<void>;
    /**
     * Sends a message to the meeting. This method can be used to send text, image,
     * or file messages. The message type is determined by the key 'type' in `message`
     * object.
     * @param message An object including the type and content of the message.
     */
    sendMessage(message: {
        type: 'text';
        message: string;
    } | {
        type: 'image';
        image: File;
    } | {
        type: 'file';
        file: File;
    }): Promise<void>;
    /**
     * Returns an array of messages sent by a specific userId.
     * @param userId The user id of the user that sent the message.
     */
    getMessagesByUser(userId: string): Message[];
    /**
     * Returns an array of 'text', 'image' or 'file' messages.
     * @param type 'text', 'image', or 'file'.
     */
    getMessagesByType(type: keyof typeof MessageType): Message[];
    /**
     * Returns an array of pinned messages.
     */
    get pinned(): Message[];
}
