import DyteMeta from './DyteMeta';
import DyteSelf from './DyteSelf';
import DyteParticipants from './DyteParticipants';
import DytePlugins from './DytePlugins';
import DyteChat from './DyteChat';
import DytePolls from './DytePolls';
import DyteRemote from './DyteRemote';
import DyteRecording from './DyteRecording';
/**
 * The DyteClient class is the main class of the web core library.
 * An object of the DyteClient class can be created using
 * `await DyteClient.init({ ... })`. Typically, an object of `DyteClient` is
 * named `meeting`.
 * @module DyteClient
 * @typicalname meeting
 */
export default class DyteClient {
    #private;
    private constructor();
    /**
     * The `init` method can be used to instantiate the DyteClient class.
     * This returns an instance of DyteClient, which can be used to perform
     * actions on the meeting.
     * @param options The options object.
     * @param options.roomName The name of the room.
     * @param options.authToken The authorization token received using the API.
     * @param options.apiBase The base URL of the API.
     * @param options.defaults The default audio and video settings.
     */
    static init(options: {
        roomName: string;
        authToken: string;
        apiBase?: string;
        defaults?: {
            video?: boolean;
            audio?: boolean;
        };
        modules?: any;
    }): Promise<DyteClient>;
    /**
     * The `joinRoom()` method can be used to join the meeting. A `roomJoined` event
     * is emitted on `self` when the room is joined successfully.
     */
    joinRoom(): Promise<void>;
    /**
     * The `leaveRoom()` method can be used to leave a meeting.
     */
    leaveRoom(): Promise<void>;
    /**
     * The `participants` object consists of 4 maps of participants,
     * `waitlisted`, `joined`, `active`, `pinned`. The maps are indexed by
     * `peerId`s, and the values are the corresponding participant objects.
     */
    get participants(): Readonly<DyteParticipants>;
    /**
     * The `self` object can be used to manipulate audio and video settings,
     * and other configurations for the local participant. This exposes methods
     * to enable and disable media tracks, share the user's screen, etc.
     */
    get self(): Readonly<DyteSelf>;
    /**
     * The `room` object stores information about the current meeting, such
     * as chat messages, polls, room name, etc.
     */
    get meta(): Readonly<DyteMeta>;
    /**
     * The `plugins` object stores information about the plugins available in
     * the current meeting. It exposes methods to activate and deactivate them.
     */
    get plugins(): Readonly<DytePlugins>;
    /**
     * The chat object stores the chat messages that were sent in the meeting.
     * This includes text messages, images, and files.
     */
    get chat(): Readonly<DyteChat>;
    /**
     * The polls object stores the polls that were initiated in the meeting.
     * It exposes methods to create and vote on polls.
     */
    get polls(): Readonly<DytePolls>;
    /**
     * The remote object stores the remote control requests for the meeting.
     * It exposes methods to request, accept and end the remote control.
     */
    get remote(): Readonly<DyteRemote>;
    get recording(): Readonly<DyteRecording>;
}
