import { DyteSelf } from '..';
import DyteEventEmitter from '../utils/DyteEventEmitter';
export interface DeviceConfig {
    browserName: string;
    browserVersion: string;
    isMobile: boolean;
    engineName: string;
    osName: string;
}
export interface Participant {
    id?: string;
    userId?: string;
    displayName: string;
    device?: DeviceConfig;
    picture?: string;
    isHost?: boolean;
    flags?: {
        [key: string]: string | boolean;
    };
    clientSpecificId?: string;
    audioMuted?: boolean;
    audioTrack?: MediaStreamTrack;
    videoTrack?: MediaStreamTrack;
    videoEnabled?: boolean;
}
/**
 * This module represents a single participant in the meeting.
 * The participant object can be accessed from one of the participant lists
 * present in the `meeting.participants` object. For example,
 * ```ts
 * const participant1 = meeting.participants.active.get(participantId);
 * const participant2 = meeting.participants.joined.get(participantId);
 * const participant3 = meeting.participants.active.toArray()[0];
 * const participant4 = meeting.participants.active.toArray().filter((p) => p.name === 'John');
 * ```
 * @module DyteParticipant
 * @typicalname participant
 */
export default class DyteParticipant extends DyteEventEmitter {
    #private;
    /**
     * The peer ID of the participant.
     * The participants are indexed by this ID in the participant map.
     */
    id: string;
    /**
     * The user ID of the participant.
     */
    userId: string;
    /**
     * The name of the participant.
     */
    name: string;
    /**
     * The picture of the participant.
     */
    picture: string;
    isHost: boolean;
    /**
     * The clientSpecificId of the participant.
     */
    clientSpecificId?: string;
    flags: {
        [key: string]: string | boolean;
    };
    /**
     * The device configuration of the participant.
     */
    device: DeviceConfig;
    /**
     * The participant's video track.
     */
    videoTrack: MediaStreamTrack;
    /**
     * The participant's audio track.
     */
    audioTrack: MediaStreamTrack;
    /**
     * The participant's screenshare video and audio track.
     */
    screenShareTracks: {
        audio: MediaStreamTrack;
        video: MediaStreamTrack;
    };
    /**
     * This is true if the participant's video is enabled.
     */
    videoEnabled: boolean;
    /**
     * This is true if the participant's audio is enabled.
     */
    audioEnabled: boolean;
    /**
     * This is true if the participant is screensharing.
     */
    screenShareEnabled: boolean;
    /**
     * This is true if the dyte participant supports remote control.
     */
    supportsRemoteControl: boolean;
    constructor(participant: Participant, self: DyteSelf, roomNodeClient: any);
    setVideoEnabled(videoEnabled: boolean, emitEvent?: boolean): void;
    setAudioEnabled(audioEnabled: boolean, emitEvent?: boolean): void;
    setScreenShareEnabled(screenShareEnabled: boolean, emitEvent?: boolean): void;
    /**
     * Returns `participant.id` if user has permission
     * to pin participants.
     */
    pin(): Promise<void>;
    /**
     * Returns `participant.id` if user has permission
     * to unpin participants.
     */
    unpin(): Promise<void>;
    /**
     * @access private
     * Not for external use
     */
    setIsPinned(isPinned: boolean, emitEvent?: boolean): void;
    /**
     * Disables audio for this participant.
     * Requires the permission to disable participant audio.
    */
    disableAudio(): Promise<void>;
    /**
     * Kicks this participant from the meeting.
     * Requires the permission to kick a participant.
    */
    kick(): Promise<void>;
    /**
     * Disables video for this participant.
     * Requires the permission to disable video for a participant.
    */
    disableVideo(): Promise<void>;
    /**
     * Returns true if the participant is pinned.
     */
    get isPinned(): boolean;
}
