import DyteEventEmitter from '../utils/DyteEventEmitter';
import DyteParticipant from './DyteParticipant';
import DyteSelf from './DyteSelf';
import DyteParticipantMap from './map/DyteParticipantMap';
declare type ViewMode = 'ACTIVE_GRID' | 'PAGINATED';
export interface BroadcastMessagePayload {
    [key: string]: boolean | number | string | Date;
}
/**
 * This module represents all the participants in the meeting (except the local user).
 * It consists of 4 maps:
 * - `joined`: A map of all participants that have joined the meeting.
 * - `waitlisted`: A map of all participants that have been added to the waitlist.
 * - `active`: A map of active participants who should be displayed in the meeting grid.
 * - `pinned`: A map of pinned participants.
 * @module DyteParticipants
 * @typicalname meeting.participants
 */
export default class DyteParticipants extends DyteEventEmitter {
    #private;
    /**
     * Returns a list of participants waiting to join the meeting.
     */
    readonly waitlisted: Readonly<DyteParticipantMap<Omit<DyteParticipant, 'audioTrack' | 'videoTrack' | 'screenShareTracks'>>>;
    /**
     * Returns a list of all participants in the meeting.
     */
    readonly joined: Readonly<DyteParticipantMap>;
    /**
     * Returns a list of participants whose streams are currently consumed.
     */
    readonly active: Readonly<DyteParticipantMap>;
    /**
     * Returns a list of participants who have been pinned.
     */
    readonly pinned: Readonly<DyteParticipantMap>;
    /**
     * Indicates whether the meeting is in 'ACTIVE_GRID' mode or 'PAGINATED' mode.
     *
     * In 'ACTIVE_GRID' mode, participants are populated in the participants.active map
     * dynamically. The participants present in the map will keep changing when other
     * participants unmute their audio or turn on their videos.
     *
     * In 'PAGINATED' mode, participants are populated in the participants.active map
     * just once, and the participants in the map will only change if the page number is
     * changed by the user using setPage(page).
     */
    viewMode: ViewMode;
    /**
     * This indicates the current page that has been set by the user in PAGINATED mode.
     * If the meeting is in ACTIVE_GRID mode, this value will be 0.
     */
    currentPage: number;
    /**
     * This stores the `participantId` of the last participant who spoke in the meeting.
     */
    lastActiveSpeaker: string;
    constructor(self: DyteSelf);
    /**
     * Returns the number of participants who are joined in the meeting.
     */
    get count(): number;
    /**
     * Returns the maximum number of participants that can be present in
     * the active map.
     */
    get maxActiveParticipantsCount(): number;
    /**
     * Returns the number of pages that are available in the meeting in PAGINATED mode.
     * If the meeting is in ACTIVE_GRID mode, this value will be 0.
     */
    get pageCount(): number;
    /**
     * Accepts requests from waitlisted participants if user
     * has appropriate permissions.
     * @param id participantId of the waitlisted participant.
     */
    acceptWaitingRoomRequest(id: string): Promise<void>;
    /**
     * Rejects requests from waitlisted participants if user
     * has appropriate permissions.
     * @param id participantId of the waitlisted participant.
     */
    rejectWaitingRoomRequest(id: string): Promise<void>;
    /**
     * Sets the view mode of the meeting to either ACTIVE_GRID or PAGINATED.
     * @param viewMode The mode in which the active map should be populated
     */
    setViewMode(viewMode: ViewMode): Promise<void>;
    /**
     * Populates the active map with participants present in the page number
     * indicated by the parameter `page` in PAGINATED mode.
     * Does not do anything in ACTIVE_GRID mode.
     * @param page The page number to be set.
     */
    setPage(page: number): Promise<void>;
    /**
     * Disables audio for all participants in the meeting.
     * @param allowUnMute Allow participants to unmute after they are muted.
     */
    disableAllAudio(allowUnMute: boolean): Promise<void>;
    /**
     * Disables video for all participants in the meeting.
     */
    disableAllVideo(): Promise<void>;
    /**
     * @deprecated
     * Disables audio for the given participant.
     * @param participantId ID of participant to be muted.
     */
    disableAudio(peerId: string): Promise<void>;
    /**
     * @deprecated
     * Disables video for the given participant.
     * @param participantId ID of participant to be muted.
     */
    disableVideo(peerId: string): Promise<void>;
    /**
     * Kicks all participants from the meeting.
     */
    kickAll(): Promise<void>;
    /**
     * Broadcasts the message to all participants including `self`.
     */
    kick(peerId: string): Promise<void>;
    /**
     * Add mock participants from the meeting.
     * @param count number of participants
     * @param count number of active participant
     */
    mockAddParticipants(count: number, activeCount: number): Promise<void>;
}
export {};
