/**
 * TODO(roerohan): separate the inner objects into separate interfaces
 * so that we can use the same types in the get methods in the
 * class instead of having to rewrite them.
 */
export interface PresetPermissions {
    viewType: string;
    acceptWaitingRequests: boolean;
    requestProduce: boolean;
    canAllowParticipantAudio: boolean;
    canAllowParticipantScreensharing: boolean;
    canAllowParticipantVideo: boolean;
    requestKickParticipant: boolean;
    kickParticipant: boolean;
    pinParticipant: boolean;
    canRecord: boolean;
    waitingRoomType: string;
    plugins: {
        canClose: boolean;
        canStart: boolean;
        canEditAcl: boolean;
        config: {
            [key: string]: any;
        };
    };
    polls: {
        canCreate: boolean;
        canVote: boolean;
        canView: boolean;
    };
    produce: {
        video: {
            allow: boolean;
            quality: string;
            frameRate: number;
        };
        audio: boolean;
        screenshare: {
            allow: boolean;
            quality: string;
            frameRate: number;
        };
    };
    chat: {
        public: {
            canSend: boolean;
            text: boolean;
            files: boolean;
        };
        private: {
            canSend: boolean;
            canReceive: boolean;
            text: boolean;
            files: boolean;
        };
    };
    reactions: boolean;
    hiddenParticipant: boolean;
    showParticipantList: boolean;
    canChangeParticipantRole: boolean;
    canChangeTheme: boolean;
    canPresent: boolean;
    acceptPresentRequests: boolean;
    canEditDisplayName: boolean;
    maxScreenshareCount: number;
    isRecorder: boolean;
}
export declare const DEFAULT_PERMISSIONS_CAMEL_CASED: {
    viewType: string;
    acceptWaitingRequests: boolean;
    requestProduce: boolean;
    canAllowParticipantAudio: boolean;
    canAllowParticipantScreensharing: boolean;
    canAllowParticipantVideo: boolean;
    requestKickParticipant: boolean;
    kickParticipant: boolean;
    pinParticipant: boolean;
    canRecord: boolean;
    waitingRoomType: string;
    plugins: {
        canClose: boolean;
        canStart: boolean;
        canEditAcl: boolean;
        config: {};
    };
    polls: {
        canCreate: boolean;
        canVote: boolean;
        canView: boolean;
    };
    produce: {
        video: {
            allow: boolean;
            quality: string;
            frameRate: number;
        };
        audio: boolean;
        screenshare: {
            allow: boolean;
            quality: string;
            frameRate: number;
        };
    };
    chat: {
        public: {
            canSend: boolean;
            text: boolean;
            files: boolean;
        };
        private: {
            canSend: boolean;
            canReceive: boolean;
            text: boolean;
            files: boolean;
        };
    };
    reactions: boolean;
    hiddenParticipant: boolean;
    showParticipantList: boolean;
    canChangeParticipantRole: boolean;
    canChangeTheme: boolean;
    canPresent: boolean;
    acceptPresentRequests: boolean;
    canEditDisplayName: boolean;
    maxScreenshareCount: number;
    isRecorder: boolean;
};
/**
 * The DytePermissionsPreset class represents the meeting permissions for the current participant
 * @module DytePermissionsPreset
 * @typicalname meeting.self.permissions
 */
export default class DytePermissionsPreset {
    #private;
    private constructor();
    static fromResponse(response: PresetPermissions): DytePermissionsPreset;
    static default(): DytePermissionsPreset;
    /**
     * The `viewType` tells the type of the meeting
     * possible values are WEBINAR, GROUPCALL
     */
    get viewType(): Readonly<string>;
    /**
     * The `acceptWaitingRequests` returns boolean value.
     * If `true`, participant can accept the request of waiting participant.
     */
    get acceptWaitingRequests(): Readonly<boolean>;
    /**
     * The `requestProduce` returns boolean value.
     * If `true`, participant can send request to participants
     * about producing audio, video or screenshare.
     */
    get requestProduce(): Readonly<boolean>;
    /**
     * The `canAllowParticipantAudio` returns boolean value.
     * If `true`, participant can enable other participants` audio.
     */
    get canAllowParticipantAudio(): Readonly<boolean>;
    /**
     * The `canAllowParticipantScreensharing` returns boolean value.
     * If `true`, participant can enable other participants` screen share.
     */
    get canAllowParticipantScreensharing(): Readonly<boolean>;
    /**
     * The `canAllowParticipantVideo` returns boolean value.
     * If `true`, participant can enable other participants` video.
     */
    get canAllowParticipantVideo(): Readonly<boolean>;
    /**
     * The `requestKickParticipant` returns boolean value.
     * If `true`, participant can request to remove another participant from the meeting.
     */
    get requestKickParticipant(): Readonly<boolean>;
    /**
     * The `kickParticipant` returns boolean value.
     * If `true`, participant can remove other participants from the meeting.
     */
    get kickParticipant(): Readonly<boolean>;
    /**
     * The `pinParticipant` returns boolean value.
     * If `true`, participant can pin a participant in the meeting.
     */
    get pinParticipant(): Readonly<boolean>;
    /**
     * The `canRecord` returns boolean value.
     * If `true`, participant can record the meeting.
     */
    get canRecord(): Readonly<boolean>;
    /**
     * The `waitingRoomType` returns string value.
     * type of waiting room behavior
     * possible values are `SKIP_ON_ACCEPT`, `ON_ACCEPT`, `SKIP_ON_PRIVILEGED_USER_ENTRY`
     */
    get waitingRoomType(): Readonly<string>;
    /**
     * The `plugins` tells if the participant can act on plugins
     * there are 2 permissions with boolean values, `canStart` and `canClose`.
     */
    get plugins(): Readonly<{
        canClose: boolean;
        canStart: boolean;
        canEditAcl: boolean;
        config: {
            [key: string]: any;
        };
    }>;
    /**
     * The `polls` tells if the participant can use polls.
     * There are 3 permissions with boolean values, `canCreate`, `canVote`, `canView`
     */
    get polls(): Readonly<{
        canCreate: boolean;
        canVote: boolean;
        canView: boolean;
    }>;
    /**
     * The `produceVideo` shows permissions for enabling video for the participant.
     * There are 3 permissions
     * `allow` - if video is allowed
     * `quality` - quality of the video
     * `frameRate` - frame rate of the video
     */
    get produceVideo(): Readonly<{
        allow: boolean;
        quality: string;
        frameRate: number;
    }>;
    /**
     * The `produceScreenshare` shows permissions for enabling screen share for the participant.
     * There are 3 permissions
     * `allow` - if sharing screen is allowed
     * `quality` - quality of the video
     * `frameRate` - frame rate of the video
     */
    get produceScreenshare(): Readonly<{
        allow: boolean;
        quality: string;
        frameRate: number;
    }>;
    /**
     * The `produceAudio` shows permissions for enabling audio for the participant.
     * If true, participant can enable audio.
     */
    get produceAudio(): Readonly<boolean>;
    /**
     * The `chatPublic` shows permissions for public chat
     * there are 4 permissions
     * `canSend` - if true, the participant can send chat
     * `text` - if true, the participant can send text
     * `files` - if true, the participant can send files
     */
    get chatPublic(): Readonly<{
        canSend: boolean;
        text: boolean;
        files: boolean;
    }>;
    /**
     * The `chatPrivate` shows permissions for public chat
     * there are 4 permissions
     * `canSend` - if true, the participant can send private chat
     * `text` - if true, the participant can send text as private chat
     * `files` - if true, the participant can send files as private chat
     * `canReceive` - (optional) if true, the participant can receive private chat
     */
    get chatPrivate(): Readonly<{
        canSend: boolean;
        text: boolean;
        files: boolean;
        canReceive?: boolean;
    }>;
    /**
     * The `reactions` returns boolean value.
     * If `true`, reactions are enabled for the participant
     */
    get reactions(): Readonly<boolean>;
    /**
     * The `hiddenParticipant` returns boolean value.
     * If `true`, participant is hidden.
     */
    get hiddenParticipant(): Readonly<boolean>;
    /**
     * The `showParticipantList` returns boolean value.
     * If `true`, participant list can be shown to the participant.
     */
    get showParticipantList(): Readonly<boolean>;
    /**
     * The `canChangeParticipantRole` returns boolean value.
     * If `true`, allow changing the participants' role.
     */
    get canChangeParticipantRole(): Readonly<boolean>;
    /**
     * The `canChangeTheme` returns boolean value.
     * If `true`, the participant can change the meeting theme.
     */
    get canChangeTheme(): Readonly<boolean>;
    /**
     * The `canPresent` returns boolean value.
     * If `true`, the participant can become a presentor.
     */
    get canPresent(): Readonly<boolean>;
    get acceptPresentRequests(): Readonly<boolean>;
    get canEditDisplayName(): Readonly<boolean>;
    get maxScreenShareCount(): Readonly<number>;
    get isRecorder(): Readonly<boolean>;
}
