import DyteEventEmitter from '../utils/DyteEventEmitter';
import DyteSelf from './DyteSelf';
export interface DytePluginResponse {
    baseURL: string;
    createdAt: string;
    description: string;
    id: string;
    name: string;
    organizationId: string;
    picture: string;
    private: boolean;
    published: boolean;
    staggered: boolean;
    tags: string[];
    type: string;
    updatedAt: string;
}
export interface PluginConfig {
    name: string;
    pluginId: string;
    version: string;
    description: string;
    author?: string;
    repository?: string;
    tags?: string[];
    picture?: string;
    url?: string;
    files: {
        include: string[];
        exclude?: string[];
    };
    views?: {
        [viewId: string]: {
            url: string;
            suggestedPosition: string;
        };
    };
    contentScript?: string;
    permissions?: {
        [key: string]: {
            default: boolean;
            description: string;
        };
    };
    config?: {
        [key: string]: string;
    };
}
export interface PluginIframeMessage {
    type: number;
    uuid: string;
    payload?: any;
}
/**
 * The DytePlugin module represents a single plugin in the meeting.
 * A plugin can be obtained from one of the plugin arrays in `meeting.plugins`.
 * For example,
 * ```ts
 * const plugin1 = meeting.plugins.active.get(pluginId);
 * const plugin2 = meeting.plugins.all.get(pluginId);
 * ```
 * @module DytePlugin
 * @typicalname plugin
 */
export default class DytePlugin extends DyteEventEmitter {
    #private;
    readonly baseURL: string;
    readonly createdAt: Date;
    readonly description: string;
    readonly id: string;
    readonly name: string;
    readonly organizationId: string;
    readonly picture: string;
    readonly private: boolean;
    readonly published: boolean;
    readonly staggered: boolean;
    readonly tags: string[];
    readonly type: string;
    readonly updatedAt: Date;
    config?: PluginConfig;
    active: boolean;
    iframes: Map<string, {
        iframe: HTMLIFrameElement;
        listener: (message: MessageEvent) => void;
    }>;
    constructor({ baseURL, createdAt, description, id, name, organizationId, picture, private: isPrivate, published, staggered, tags, type, updatedAt, }: DytePluginResponse, self: DyteSelf);
    /**
     * @access private
     * This function forwards events to plugin. This is not meant for external use.
     * @param message Socket message forwarded to this plugin.
     */
    sendIframeEvent(message: any): boolean;
    private handleIframeMessage;
    /**
     * This method is used to send arbitrary data to the plugin.
     * @param data The data that you want to send inside the plugin.
     */
    sendData(data: any): void;
    /**
     * This method is used for cleaning up event listeners attached to an iframe. It must
     * be used before the iframe is removed from the DOM.
     * @param viewId ID of the view corresponding to this iframe. Default is 'default'.
     */
    removePluginView(viewId?: string): void;
    /**
     * This method adds the communcation layer between the plugin inside the iframe
     * and the core application (meeting object) in the main window.
     * @param iframe Iframe element to display this plugin.
     * @param viewId ID of the view corresponding to this iframe. Default is 'default'.
     */
    addPluginView(iframe: HTMLIFrameElement, viewId?: string): void;
    private setActive;
    /**
     * Enable this plugin for the current user.
     */
    enable(): Promise<void>;
    /**
     * Disable this plugin for the current user.
     */
    disable(): void;
    /**
     * Activate this plugin for all participants.
     */
    activate(): Promise<void>;
    /**
     * Deactivate this plugin for all participants.
     */
    deactivate(): Promise<void>;
}
