import DyteEventEmitter from '../utils/DyteEventEmitter';
import DytePermissionsPreset from './DytePermissionsPreset';
import DyteThemePreset from './DyteThemePreset';
import LocalMediaHandler from '../media/LocalMediaHandler';
import { AudioMiddleware, VideoMiddleware } from '../media/MediaMiddlewareUtils';
import type { DeviceConfig } from './DyteParticipant';
export interface UserDetailsResponse {
    id: string;
    name: string;
    email: string;
    picture?: string;
    loggedIn?: boolean;
    scope?: string[];
    clientSpecificId?: string | number;
    organizationId?: string;
}
/**
 * The DyteSelf module represents the current user, and allows to modify the state
 * of the user in the meeting. The audio and video streams of the user can be retrieved from
 * this module.
 * @module DyteSelf
 * @typicalname meeting.self
 */
export default class DyteSelf extends DyteEventEmitter {
    #private;
    id: string;
    name: string;
    picture: string;
    clientSpecificId: any;
    waitlistStatus: 'accepted' | 'waiting' | 'rejected' | 'none';
    preview: Pick<LocalMediaHandler, 'audioTrack' | 'audioEnabled' | 'videoTrack' | 'videoEnabled'>;
    role: any;
    userId: string;
    organizationId: string;
    supportsRemoteControl: boolean;
    device: DeviceConfig;
    private constructor();
    static init(defaults: {
        video?: boolean;
        audio?: boolean;
    }): Promise<DyteSelf>;
    private setupEvents;
    /**
     * Returns the `audioTrack`.
     */
    get audioTrack(): MediaStreamTrack;
    /**
     * Returns the `rawAudioTrack` having no middleware executed on it.
     */
    get rawAudioTrack(): MediaStreamTrack;
    /**
     * Adds the audio middleware to be executed on the raw audio stream.
     * If there are more than 1 audio middlewares,
     * they will be executed in the sequence they were added in.
     * If you want the sequence to be altered, please remove all previous middlewares and re-add.
     */
    addAudioMiddleware(audioMiddleware: AudioMiddleware): Promise<{
        success: boolean;
        message: string;
    }>;
    /**
    * Removes the audio middleware, if it is there.
    */
    removeAudioMiddleware(audioMiddleware: AudioMiddleware): Promise<{
        success: boolean;
        message: string;
    }>;
    /**
     * Returns the `videoTrack`.
     */
    get videoTrack(): MediaStreamTrack;
    /**
     * Returns the `videoTrack` having no middleware executed on it.
     */
    get rawVideoTrack(): MediaStreamTrack;
    /**
     * Adds the video middleware to be executed on the raw video stream.
     * If there are more than 1 video middlewares,
     * they will be executed in the sequence they were added in.
     * If you want the sequence to be altered, please remove all previous middlewares and re-add.
     */
    addVideoMiddleware(videoMiddleware: VideoMiddleware): Promise<{
        success: boolean;
        message: string;
    }>;
    /**
     * Removes the video middleware, if it is there.
     */
    removeVideoMiddleware(videoMiddleware: VideoMiddleware): Promise<{
        success: boolean;
        message: string;
    }>;
    /**
     * Returns the screen share tracks.
     */
    get screenShareTracks(): {
        audio?: MediaStreamTrack;
        video?: MediaStreamTrack;
    };
    /**
     * Returns true if audio is enabled.
     */
    get audioEnabled(): boolean;
    /**
     * Returns true if video is enabled.
     */
    get videoEnabled(): boolean;
    /**
     * Returns true if screen share is enabled.
     */
    get screenShareEnabled(): boolean;
    /**
     * Returns the current audio and video permissions given by the user.
     * 'ACCEPTED' if the user has given permission to use the media.
     * 'DENIED' if the user has denied permission to use the media.
     * 'SYS_DENIED' if the user's system has denied permission to use the media.
     * 'UNAVAILABLE' if the media is not available (or being used by a different application).
     */
    get mediaPermissions(): {
        audio?: "NOT_REQUESTED" | "ACCEPTED" | "DENIED" | "SYSTEM_DENIED" | "COULD_NOT_START";
        video?: "NOT_REQUESTED" | "ACCEPTED" | "DENIED" | "SYSTEM_DENIED" | "COULD_NOT_START";
        screenshare?: "NOT_REQUESTED" | "ACCEPTED" | "DENIED" | "SYSTEM_DENIED" | "COULD_NOT_START";
    };
    /**
     * Returns the current permission given to the user for the meeting.
     */
    get permissions(): DytePermissionsPreset;
    /**
     * Returns suggested theme for the meeting.
     */
    get suggestedTheme(): DyteThemePreset;
    /**
     * Returns true if the local participant has joined the meeting.
     */
    get roomJoined(): boolean;
    /**
     * The name of the user can be set by calling this method.
     * This will get reflected to other participants ONLY if
     * this method is called before the room is joined.
     * @param name Name of the user.
     */
    setName(name: string): void;
    /**
     * Sets up the local media tracks.
     * @param options The audio and video options.
     * @param options.video If true, the video stream is fetched.
     * @param options.audio If true, the audio stream is fetched.
     */
    setupTracks(options?: {
        video?: boolean;
        audio?: boolean;
    }): Promise<void>;
    /**
     * This method is used to unmute the local participant's audio.
     */
    enableAudio(): Promise<void>;
    /**
     * This method is used to start streaming the local participant's video
     * to the meeting.
     */
    enableVideo(): Promise<void>;
    /**
     * This method is used to start sharing the local participant's screen
     * to the meeting.
     */
    enableScreenShare(): Promise<void>;
    /**
     * This method is used to mute the local participant's audio.
     */
    disableAudio(): Promise<void>;
    /**
     * This participant is used to disable the local participant's video.
     */
    disableVideo(): Promise<void>;
    /**
     * This method is used to stop sharing the local participant's screen.
     */
    disableScreenShare(): Promise<void>;
    /**
     * Enable a preview for audio and video. This will populate preview.audioTrack
     * and preview.videoTrack. You can check if the streams are enabled in the preview
     * using preview.audioEnabled and preview.videoEnabled.
     * @param options The audio and video options.
     * @param options.video If true, the video stream is fetched.
     * @param options.audio If true, the audio stream is fetched.
     */
    enablePreview(options?: {
        audio?: boolean;
        video?: boolean;
    }): Promise<void>;
    /**
     * Disable the audio and/or video tracks of the preview.
     */
    disablePreview(options?: {
        audio?: boolean;
        video?: boolean;
    }): Promise<void>;
    /**
     * Returns the media devices currently being used.
     */
    getCurrentDevices(): {
        audio: MediaDeviceInfo;
        video: MediaDeviceInfo;
        speaker: MediaDeviceInfo;
    };
    /**
     * Returns the local participant's audio devices.
     */
    getAudioDevices(): MediaDeviceInfo[];
    /**
     * Returns the local participant's video devices.
     */
    getVideoDevices(): MediaDeviceInfo[];
    /**
     * Returns the local participant's speaker devices.
     */
    getSpeakerDevices(): MediaDeviceInfo[];
    /**
     * Returns the local participant's device, indexed by ID and kind.
     * @param deviceId The ID of the device.
     * @param kind The kind of the device: audio, video, or speaker.
     */
    getDeviceById(deviceId: string, kind: 'audio' | 'video' | 'speaker'): MediaDeviceInfo;
    /**
     * Returns all media devices accessible by the local participant.
     */
    getAllDevices(): MediaDeviceInfo[];
    /**
     * @access private
     * Not for external use.
     */
    setIsPinned(isPinned: boolean, emitEvent?: boolean): void;
    /**
     * Returns true if the current user is pinned.
     */
    get isPinned(): boolean;
    /**
     * Returns `self.id` if user has permission
     * to pin participants.
     */
    pin(): Promise<void>;
    /**
     * Returns `self.id` if user has permission
     * to unpin participants.
     */
    unpin(): Promise<void>;
    /**
     * Change the current media device that is being used by the local participant.
     * @param device The device that is to be used. A device of the same `kind` will be replaced.
     * @param preview If true, the device will be changed for the preview, otherwise it will affect
     * the primary stream.
     */
    setDevice(device: MediaDeviceInfo, preview?: boolean): Promise<void>;
}
